"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var google_libphonenumber_1 = require("google-libphonenumber");
var auth_1 = require("../test/auth");
var client;
var phoneUtil = google_libphonenumber_1.PhoneNumberUtil.getInstance();
before(function () {
    return auth_1.default.then(function (c) { return client = c; });
});
describe("Note", function () {
    var _this = this;
    it("Create, update, query, and delete a note", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var note, res, noteId, updates, createdNote, delRes;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    note = { externalID: "1898", commentingPerson: { id: 791599 }, personReference: { id: 1045032, _subtype: "Candidate" }, comments: "Test note, ----- create by REST API." + Date.now(), action: "hello" };
                    return [4 /*yield*/, client.createNote(note)];
                case 1:
                    res = _a.sent();
                    noteId = res.changedEntityId;
                    chai_1.expect(noteId).to.not.null;
                    chai_1.expect(res.changedEntityType).to.equal('Note');
                    chai_1.expect(res.changeType).to.equal('INSERT');
                    chai_1.expect(res.data).to.deep.equal(note);
                    updates = { minutesSpent: 678, action: 'Inbound' };
                    return [4 /*yield*/, client.updateNote(res.changedEntityId, updates)];
                case 2:
                    res = _a.sent();
                    chai_1.expect(res).to.deep.equal({
                        changedEntityType: 'Note',
                        changedEntityId: noteId,
                        changeType: 'UPDATE',
                        data: updates
                    });
                    return [4 /*yield*/, client.getNote(noteId, ['externalID', 'commentingPerson(id)', 'personReference(id)', 'comments', 'action', 'minutesSpent'])];
                case 3:
                    createdNote = _a.sent();
                    delete createdNote.commentingPerson['_subtype'];
                    delete createdNote.commentingPerson['firstName'];
                    delete createdNote.commentingPerson['lastName'];
                    delete createdNote.personReference['firstName'];
                    delete createdNote.personReference['lastName'];
                    chai_1.expect(createdNote).to.deep.equal(tslib_1.__assign({}, note, updates));
                    return [4 /*yield*/, client.deleteNote(res.changedEntityId)];
                case 4:
                    delRes = _a.sent();
                    chai_1.expect(delRes).to.deep.equal({
                        changedEntityType: 'Note',
                        changedEntityId: noteId,
                        changeType: 'DELETE',
                        data: {}
                    });
                    return [2 /*return*/];
            }
        });
    }); });
    it.skip("create multiple notes with same externalID", function () {
        var externalID = "888";
        var person = { id: 1045032, _subtype: "Candidate" };
        return client.createNote({ externalID: externalID, comments: "Note 1 for test same externalID", commentingPerson: { id: 8 }, personReference: person }).then(function (note) {
            console.log("Note 1 created", note);
            return client.createNote({ externalID: externalID, comments: "Note 2 for test same externalID", commentingPerson: { id: 8 }, personReference: person });
        }).then(function (note) {
            console.log("Note 2 created", note);
        });
    });
    it.skip("updates note not exists", function () {
        return client.updateNote(9255440000, { comments: "Updated containt for note" }).then(function (note) {
            console.log("Updated note", note);
        });
    });
});
describe('Query', function () {
    it('queryCorporateUsersByPhoneNumbers', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        function addNumber(number) {
            var p;
            try {
                p = phoneUtil.parse(number, 'US');
            }
            catch (e) {
                //console.log('error parse phone number ' + number, e, )
                return;
            }
            var e164 = phoneUtil.format(p, google_libphonenumber_1.PhoneNumberFormat.E164);
            if (number == e164 || number == phoneUtil.format(p, google_libphonenumber_1.PhoneNumberFormat.NATIONAL) || number == phoneUtil.format(p, google_libphonenumber_1.PhoneNumberFormat.INTERNATIONAL)) {
                phones.add(e164);
                return true;
            }
        }
        var users, phones, phoneFields, _i, phoneFields_1, phoneFld, res_1, res;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    users = [];
                    phones = new Set();
                    phoneFields = ['phone', 'mobile'];
                    _i = 0, phoneFields_1 = phoneFields;
                    _a.label = 1;
                case 1:
                    if (!(_i < phoneFields_1.length)) return [3 /*break*/, 4];
                    phoneFld = phoneFields_1[_i];
                    return [4 /*yield*/, client.query('CorporateUser', { count: 100, where: phoneFld + "<>' ' and " + phoneFld + "<>'0' and " + phoneFld + " is not null", fields: ['*'], orderBy: ['-id'] })];
                case 2:
                    res_1 = _a.sent();
                    res_1.data.forEach(function (user) {
                        if (addNumber(user.phone) || addNumber(user.mobile)) {
                            users.push(user);
                        }
                    });
                    _a.label = 3;
                case 3:
                    _i++;
                    return [3 /*break*/, 1];
                case 4: return [4 /*yield*/, client.queryCorporateUsersByPhoneNumbers(Array.from(phones), { count: 200, fields: ['id'], orderBy: ['-id'] })];
                case 5:
                    res = _a.sent();
                    chai_1.expect(res.data.map(function (u) { return u.id; })).to.include.members(users.map(function (u) { return u.id; }));
                    return [2 /*return*/];
            }
        });
    }); });
});
