export default class RestClient {
    clientId: string;
    secret: string;
    redirectUrl: string;
    /** The api server url without path. */
    authServer: string;
    server: string;
    /**
     * Session time-to-live in minutes. Server default value is 10 minutes.
     */
    sessionTtl: number;
    /** Login to get these. */
    sessionKey?: string;
    baseUrl?: string;
    refreshToken?: string;
    agents: string[];
    constructor(opts: RestClientOpts);
    getUserAgent(): string;
    /** Require login. */
    getJson(path: string, query?: {}): Promise<any>;
    putJson(path: string, body: {}, query?: {}): Promise<any>;
    postJson(path: string, body: {}, query?: {}): Promise<any>;
    delete(path: string, query?: {}): Promise<Response>;
    /**
     * Send an authenticated API http request. If a client request contains an invalid session key, the response status is HTTP 401 (unauthorized)
     * FIXME: Some data like FormData cannot be sent multiple times.
     */
    send(endpoint: string, query?: {}, opts?: RequestInit): Promise<Response>;
    /**
     * Auth code -> token -> session key.
     * If there is an auth on the progress, second attempt will return the existing promise.
     * If already login success, will throw error.
     */
    auth(username: string, password: string): Promise<this>;
    /**
     * The client id and auth code is retrieved from the redirect url of Bullhorn oauth login page.
     * If there is an auth on the progress, second attempt will return the existing promise.
     * If already login success, will throw error.
     **/
    oauth(clientId: string, authCode: string): Promise<void>;
    /** Get the login page url. */
    oauthLoginPageUrl(opts?: {
        state?: string;
    }): string;
    logout(): Promise<any>;
    /**
     * ttl: Session time-to-live in minutes. Default value is 10 minutes.
     * errorMessage for used or expired access_token: Invalid or expired OAuth access token.
     */
    login(token: Token): Promise<void>;
    getToken(authCode: string): Promise<Token>;
    /**
     * If current session key is invalid, update it with refreshToken.
     */
    private refreshSession(refreshToken);
    /** Returns auth code. */
    getAuthCode(username: string, password: string): Promise<string>;
}
export interface RestClientOpts {
    server: string;
    authServer: string;
    clientId: string;
    secret: string;
    redictionUrl?: string;
    sessionTtl?: number;
}
export declare class Token {
    constructor(data: any);
    accessToken: string;
    type: string;
    /**
     * Valid time in seconds for accessToken. refreshToken will not never expire unless it's refreshed.
     */
    expiresIn: number;
    refreshToken: string;
}
