import CorporateUser from "./CorporateUser";
import Candidate from "./Candidate";
import ClientContact from "./ClientContact";
import NoteEntity from "./NoteEntity";
import JobOrder from "./JobOrder";
import Lead from "./Lead";
import EntityType from "./EntityType";
import Placement from "./Placement";
/**
 * Represents a note (comment) associated with a Candidate, ClientContact, CorporateUser, JobOrder, Lead, or Opportunity. Notes can be accessed via the "Notes" tab on the person's record in the Bullhorn application.
 *If you include a commentingPerson value and a personReference value when you create a Note, the association to an entity is made automatically and you do not need to make a separate call to create a NoteEntity.
 */
interface Note {
    /**
     * Id of this Note. Not null
     */
    id?: number;
    /**
     * Action type associated with Note. The list of values is configured in the private label attribute called commentActionList.
     */
    action?: string;
    /**
     * Timestamp for this Note.
     */
    bHTimestamp?: number[];
    /**
     * Person who created the Note. The default value is user who creates the Note.
     */
    commentingPerson?: CorporateUser;
    /**
     * Candidates associated with this Note. Included fields are:
     *  id
     *  firstName
     *  lastName
     */
    candidates?: Candidate[];
    /**
     * ClientContacts associated with this Note. Included fields are:
     *  id
     *  firstName lastName
     */
    clientContacts?: ClientContact[];
    /**
     * Text of this Note.
     */
    comments?: string;
    /**
     * Ids of CorporateUsers associated with this Note.
     */
    corporateUsers?: number[];
    /**
     * Date on which this record was created in the X Bullhorn system.
     */
    dateAdded?: number;
    /**
     * Date on which the Note was last modified.
     */
    dateLastModified?: number;
    /**
     * External identifier for the record, used for integrations with external datasources or custom imports.
     */
    externalID?: string;
    /**
     * Ids of NoteEntities associated with this Note.
     */
    entities?: NoteEntity[];
    /**
     * Indicates whether this record has been marked as X Deleted in the Bullhorn system.
     */
    isDeleted?: boolean;
    /**
     * Primary JobOrder associated with this Note. Included fields are:
     *  id
     *  title
     */
    jobOrder?: JobOrder[];
    /**
     * Leads associated with this Note. Included lead field is id.
     */
    leads?: Lead[];
    /**
     * Number of minutes spent on actions associated with this note, if applicable.
     */
    minutesSpent?: number;
    /**
     * Person with whom this Note is associated. X Included fields are:
        id
        _subtype
     */
    personReference?: {
        id: number;
        _subtype: EntityType;
    };
    /**
     * Ids of Placements associated with this Note.
     */
    placements?: Placement[];
}
export default Note;
